import React, { useState } from "react";
import UheppHistUI from "./UheppHistUI.jsx";

const Error = (message) => (
  <div className="alert m-3 alert-danger">
    <h4 className="alert-heading">Rendering failed</h4>
    <p>The interactive plot rendering failed with the following error message:</p>
    <p style={{fontFamily: "monospace"}}>{message}</p>
    <hr />
    <p>You can download the JSON file and try to fix the issue. Please note that
    the web rendering is yet not fully supported.</p>
  </div>)


const Uhepp = ({width, height, uhepp}) => {
  if (!uhepp) {
    return Error("Invalid uhepp data")
  }
  if (!uhepp.version) {
    return Error("Missing uhepp version")
  }
  if (uhepp.version != "0.1") {
    return Error(`Unsupported uhepp version: ${uhepp.version}`)
  }

  if (uhepp.type == "histogram") {
    return  <UheppHistUI width={width} height={height} uhepp={uhepp} />
  } else {
    return Error(`Unknown or missing plot type: ${uhepp.type}`)
  }

}

export default Uhepp;
